/********************************************************************************
*                                                                               *
*                     T h e   A d i e   T e x t   E d i t o r                   *
*                                                                               *
*********************************************************************************
* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 2 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
*********************************************************************************
* $Id: Adie.cpp,v 1.82 2002/07/25 05:32:54 fox Exp $                            *
********************************************************************************/
#include "fx.h"
#include "fxkeys.h"
#include "FXRex.h"
#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <signal.h>
#ifndef WIN32
#include <unistd.h>
#endif
#include <ctype.h>
#include "HelpWindow.h"
#include "Preferences.h"
#include "Commands.h"
#include "Hilite.h"
#include "TextWindow.h"
#include "Adie.h"
#include "icons.h"

/*
  Notes:
  - Manage TextWindows (there are more than one).
  - Open new window or open existing file in window; make sure
    no window already shows file to be opened (check based on abs pathname).
  - Common styles kept here.
  - One single collection of icons.
*/


/*******************************************************************************/

// Map
FXDEFMAP(Adie) AdieMap[]={
  FXMAPFUNC(SEL_SIGNAL,Adie::ID_QUIT,Adie::onCmdQuit),
  FXMAPFUNC(SEL_COMMAND,Adie::ID_QUIT,Adie::onCmdQuit),
  };


// Object implementation
FXIMPLEMENT(Adie,FXApp,AdieMap,ARRAYNUMBER(AdieMap))


// Make some windows
Adie::Adie(const FXString& name):FXApp(name,FXString::null){

  // Make some icons; these are shared between all text windows
  bigicon=new FXGIFIcon(this,big_gif);
  smallicon=new FXGIFIcon(this,small_gif);
  newicon=new FXGIFIcon(this,new_gif,0,IMAGE_ALPHAGUESS);
  reloadicon=new FXGIFIcon(this,reload_gif);
  openicon=new FXGIFIcon(this,open_gif);
  saveicon=new FXGIFIcon(this,save_gif);
  saveasicon=new FXGIFIcon(this,saveas_gif,0,IMAGE_ALPHAGUESS);
  printicon=new FXGIFIcon(this,print_gif);
  cuticon=new FXGIFIcon(this,cut_gif);
  copyicon=new FXGIFIcon(this,copy_gif);
  pasteicon=new FXGIFIcon(this,paste_gif);
  deleteicon=new FXGIFIcon(this,delete_gif);
  undoicon=new FXGIFIcon(this,undo_gif);
  redoicon=new FXGIFIcon(this,redo_gif);
  fontsicon=new FXGIFIcon(this,fonts_gif);
  helpicon=new FXGIFIcon(this,help_gif);
  quiticon=new FXGIFIcon(this,quit_gif);
  shiftlefticon=new FXGIFIcon(this,shiftleft_gif);
  shiftrighticon=new FXGIFIcon(this,shiftright_gif);

  searchicon=new FXGIFIcon(this,search_gif,0,IMAGE_ALPHAGUESS);
  searchnexticon=new FXGIFIcon(this,searchnext_gif,0,IMAGE_ALPHAGUESS);
  searchprevicon=new FXGIFIcon(this,searchprev_gif,0,IMAGE_ALPHAGUESS);
  bookseticon=new FXGIFIcon(this,bookset_gif);
  booknexticon=new FXGIFIcon(this,booknext_gif);
  bookprevicon=new FXGIFIcon(this,bookprev_gif);
  bookdelicon=new FXGIFIcon(this,bookdel_gif);

  // If interrupt happens, quit gracefully; we may want to
  // save edit buffer contents w/o asking if display gets
  // disconnected or if hangup signal is received.
  addSignal(SIGINT,this,ID_QUIT);
#ifndef WIN32
  addSignal(SIGQUIT,this,ID_QUIT);
  addSignal(SIGHUP,this,ID_QUIT);
  addSignal(SIGPIPE,this,ID_QUIT);
#endif
  }


// Handle quit
long Adie::onCmdQuit(FXObject*,FXSelector,void*){
  // Loop over windows, see if OK to close
  FXTRACE((1,"quit\n"));
  exit(0);
  return 1;
  }


// Get new window; should search for currently unsed window first
TextWindow *Adie::newWindow(const FXString& file){
  TextWindow *window=new TextWindow(this);
  windowlist.append(window);
  window->create();
  // FIXME set the filename
  return window;
  }


// Find window, if any, currently editing the given file
TextWindow *Adie::findWindow(const FXString& file){
  for(FXint w=0; w<windowlist.no(); w++){
    if(windowlist[w]->getFilename()==file) return windowlist[w];
    }
  return NULL;
  }


// Open existing file
TextWindow *Adie::openWindow(const FXString& file){
  TextWindow *window;

  // Check if already being edited by another window
  window=findWindow(file);
  if(window) return window;

  // Make new window
  window=newWindow("untitled");

  // Try open the file
  window->loadFile(file);

  return window;
  }


// Close window
void Adie::closeWindow(TextWindow *window){
  windowlist.remove(window);
  delete window;
  }
  
  
// Close all windows
void Adie::closeAllWindows(){
  for(int i=0; i<windowlist.no(); i++){
    delete windowlist[i];
    }
  windowlist.clear();
  }
  

// Clean up the mess
Adie::~Adie(){
  closeAllWindows();
  delete bigicon;
  delete smallicon;
  delete newicon;
  delete reloadicon;
  delete openicon;
  delete saveicon;
  delete saveasicon;
  delete printicon;
  delete cuticon;
  delete copyicon;
  delete pasteicon;
  delete deleteicon;
  delete undoicon;
  delete redoicon;
  delete fontsicon;
  delete helpicon;
  delete quiticon;
  delete shiftlefticon;
  delete shiftrighticon;
  delete searchicon;
  delete searchnexticon;
  delete searchprevicon;
  delete bookseticon;
  delete booknexticon;
  delete bookprevicon;
  delete bookdelicon;
  }

